# Armed Services Board of Contract Appeals

Please note: The Board's decisions are not published on this website on the date of issuance. Decisions are issued first to the representatives of the parties involved in the matter and are published after a minimum of 10 days have elapsed from the date of the decision. Occasionally, for administrative reasons, a decision will not be published until several weeks after the decision date. Parties should not rely on the website publication date when calculating dates for filing motions for reconsideration, appeals, or other matters.

## Published Decisions - 2016

Decision Date | ASBCA Number | Appellant/Petitioner | Judge
April |  |  |
April 22, 2016 | 60407, 60408 | L-3 Communications Integrated Systems, L.P. | Stempler
April 22, 2016 | 60184 | The Boeing Company | Stempler
April 22, 2016 | 60157 | Manson Construction Company | Stempler
April 22, 2016 | 59918 | Bushra Company | Prouty
April 22, 2016 | 59662 | Jaynes Corporation | Prouty
April 21, 2016 | 60200 | General Dynamics C4 Systems | Stempler
April 21, 2016 | 60103 | Safeco Insurance Company of America | Stempler
April 21, 2016 | 59911, 59912 | MicroTechnologies, LLC | Melnick
April 21, 2016 | 56474, 56475, 56477, 56729, 56756, 56918, 56919, 56920 | M.E.S., Inc. and Hirani Engineering & Land Surveying, P.C., d/b/a Hirani-MES, JV | Stempler
April 19, 2016 | 59757 | Jim Black Construction Company | Hartman
April 19, 2016 | 58222, 58282, 58283, 58367, 58370, 58581 | ACI-SCC JV | Hartman
April 18, 2016 | 59762 | Torion Technologies, Inc. | Prouty
April 15, 2016 | 59624 | Rex Systems Inc. | Prouty
April 14, 2016 | 59844, 59845, 59846, 59847, 59848, 59849, 59850 | Shneez Veritas LLC | Stempler
April 14, 2016 | 59262 | Watts Webcor Obayashi, a Joint Venture | Stempler
April 14, 2016 | 59580 | The Boeing Company | Stempler
April 14, 2016 | 60387 | Afghan Active Group (AAG) | Prouty
April 12, 2016 | 60274, 60417 | Vetco Contracting Services, LLC | Stempler
April 12, 2016 | 59285 | RockCrest Investments, LLC d.b.a NewTech | Newsom
April 6, 2016 | 59696 | Third Coast Fresh Distribution, L.L.C. | Melnick
April 6, 2016 | 58819 | 554 Bloomfield LLC | Stempler
April 6, 2016 | 60325 | Great America Construction Company | Stempler
April 6, 2016 | 59113 | Human Technologies Corp. | Stempler
April 4, 2016 | 58781 | THR Enterprises, Inc. | Scott
April 4, 2016 | 59789 | Kiewit Building Group, Inc. | Scott
April 4, 2016 | 58538 | Dellew Corporation | Page
April 1, 2016 | 60072, 60073, 60074, 60075, 60076, 60077 | Global Engineering & Construction, LLC | Delman
March |  |  |
March 30, 2016 | 60177 | Dawson-Alamo1 JV, LLC | Stempler
March 30, 2016 | 58598, 58599 | AeroVironment, Inc. | Peacock
March 30, 2016 | 58243 | Highland Al Hujaz Co., Ltd. | Thrasher
March 29, 2016 | 60369 | Kevin Diaz | Stempler
March 29, 2016 | 60078 | Patriot Construction, Inc. | Stempler
March 29, 2016 | 57743, 57798, 58280 | Raytheon Company | Scott
March 25, 2016 | 60175 | Contrack Watts, Inc., f/k/a Contrak International, Inc. | Stempler
March 25, 2016 | 60164 | HK&S Construction Holding Corp. | McIlmail
March 24, 2016 | 59868 | Ahjar Shat Alarab Albidhaa Co. | Delman
March 24, 2016 | 59298, 60119 | DynPort Vaccine Company, LLC | Hartman
March 24, 2016 | 59081, 60043 | Joseph Sottolano | McIlmail
March 23, 2016 | 60333 | Gulf Group, Inc. | Hartman
March 23, 2016 | 60329 | Goodwill Easter Seals of Miami Valley | Thrasher
March 23, 2016 | 60295 | American Technical Services, Inc. | Stempler
March 23, 2016 | 60033 | Atlantic Wire & Rigging, Inc. | Hartman
March 22, 2016 | 58633 | Engineering Solutions & Products, LLC | Paul
March 22, 2016 | 58981 | River Ridge Development Authority | Clarke
March 21, 2016 | 59036, 59037 | Suodor Al-Khair Co - SAKCO for General Trading | Melnick
March 18, 2016 | 60225 | Excellims Corporation | Stempler
March 17, 2016 | 59843 | Air Services, Inc. | Melnick
March 16, 2016 | 59990, 59993, 59995, 59997, 60151 | ECC-RMA, LLC | Peacock
March 16, 2016 | 60166 | INDUS Corporation | Stempler
March 16, 2016 | 60206 | Caddell/Whitesell-Green, A Joint Venture | Stempler
March 16, 2016 | 60313 | Signature Elevator Company, Inc. | Younger
March 15, 2016 | 60234 | Botach Tactical | Stempler
March 11, 2016 | 57693 | SIA Construction, Inc. | Wilson
March 11, 2016 | 59223 | EDO Communications & Countermeasures Systems Inc. | Peacock
March 11, 2016 | 60489 | Tepa EC, LLC | Peacock
March 11, 2016 | 60458 | Tepa EC, LLC | Peacock
March 9, 2016 | 57618, 58515 | ERKA Construction Co., Ltd. | O'Connell
March 9, 2016 | 59552 | Northrop Grumman Corporation | Stempler
March 9, 2016 | 60324 | RLM Communications, Inc. | Stempler
March 8, 2016 | 59305, 59306, 59307, 59308, 59309, 59310 | VLOX, LLC | McIlmail
March 7, 2016 | 59446 | Tessada & Associates, Inc. | Delman
March 7, 2016 | 59749 | Marshall's Electric, Inc. | Delman
March 7, 2016 | 59041 | Lee's Ford Dock, Inc. | Clarke
March 4, 2016 | 58789 | Tech Projects, LLC | Younger
March 4, 2016 | 60356 | Monroe Infrared Technology | Stempler
March 3, 2016 | 59064, 59332, 59334 | Dick Pacific Construction Company, Ltd. | Clarke
March 3, 2016 | 60004 | Omran Holding Group | Stempler
March 3, 2016 | 57675, 57806, 58149, 58150, 58151, 58174, 60474 | Dick Pacific Construction Company, Ltd. | Clarke
March 3, 2016 | 58512 | KBJ, Inc. | Scott
March 2, 2016 | 59882 | Suffolk Construction Company, Inc. | Stempler
March 2, 2016 | 60359-962, 60360-963, 60361-964, 60362-965, 60363-966 | Framaco-Epik-Metis, JV | Stempler
March 2, 2016 | 58945, 58946 | Combat Support Associates | McIlmail
March 1, 2016 | 59486 | George Hicks Construction, Inc. | Thrasher
March 1, 2016 | 60353 | MicroTechnologies, LLC | Paul
March 1, 2016 | 60116 | Defense Holdings, Inc. | Stempler
March 1, 2016 | 60390 | Northrop Grumman Corporation | Stempler
March 1, 2016 | 60083 | Sacred Power Corporation | Stempler
March 1, 2016 | 58432, 58441, 58442 | Clean by Lucy, Inc. | Thrasher
February |  |  |
February 24, 2016 | 60405 | Kuryapi Insaat Taahhut Ve Ticaret Ltd St | Stempler
February 24, 2016 | 60404 | Kuryapi Insaat Taahhut Ve Ticaret Ltd St | Stempler
February 24, 2016 | 60290 | Military Aircraft Parts | O'Sullivan
February 23, 2016 | 59799, 59800 | CACI International, Inc. | Stempler
February 19, 2016 | 58001 | Symetrics Industries, LLC | Hartman
February 19, 2016 | 59735 | Rawaat Algaidaa Co. | Younger
February 18, 2016 | 59881 | Anwar Alsabah Company | O'Connell
February 18, 2016 | 60418 | Military Aircraft Parts | Paul
February 17, 2016 | 58346 | Lael Al Sahab & Co. | Melnick
February 17, 2016 | 58676 | SupplyCore, Inc. | Wilson
February 17, 2016 | 59108 | Laguna Construction Company, Inc. | Delman
February 17, 2016 | 59666 | SoCo-Piedmont, J.V., LLC | O'Sullivan
February 17, 2016 | 59673, 59674 | SOC LLC (dba SOC Nevada LLC) | Younger
February 16, 2016 | 59218 | The Boeing Company | Stempler
February 12, 2016 | 59981 | Ikhana LLC | O'Sullivan
February 11, 2016 | 59780 | The Boeing Company | Stempler
February 10, 2016 | 59047 | Blackhawk Ventures, LLC | Page
February 10, 2016 | 60207 | Aetna Government Health Plans | McIlmail
February 9, 2016 | 59026, 59284 | Scale Structure/ARCC Joint Venture | Page
February 9, 2016 | 59073, 59150 | ENCO Industries, Inc. | Clarke
February 9, 2016 | 59627 | Gas Turbine Engines, Inc. | Stempler
February 9, 2016 | 59659 | Northrop Grumman Aerospace Systems | Stempler
February 9, 2016 | 60025 | Shavers-Whittle Construction, LLC | McIlmail
February 9, 2016 | 60109 | Omnivox LLC | Stempler
February 8, 2016 | 57322 | ADT Construction Group, Inc. by Timothy S. Cory, Chapter 7 Trustee | Shackleford
February 8, 2016 | 55307 | ADT Construction Group, Inc. by Timothy S. Cory, Chapter 7 Trustee | Shackleford
February 8, 2016 | 58198 | Hanley Industries, Inc. | Melnick
February 8. 2016 | 59802, 59856, 60016, 60306 | Sulphur Springs Valley Electric Cooperative, Inc. | McIlmail
February 4, 2016 | 58749, 58836, 58837 | Technologists, Inc. | McIlmail
February 4, 2016 | 58574 | KBY International Construction Co. | Melnick
February 4, 2016 | 59665 | International Automotriz | Newsom
February 4, 2016 | 59296 | Rick Garcia Construction Company | Peacock
February 4, 2016 | 60290 | Military Aircraft Parts | O'Sullivan
February 3, 2016 | 58915 | The Boeing Company | Stempler
February 3, 2016 | 58916 | The Boeing Company | Stempler
February 3, 2016 | 58960, 58961 | Thorpe See-Op Corporation | McIlmail
February 3, 2016 | 59028 | M+W High Tech Projects Israel Ltd | Peacock
February 3, 2016 | 59862, 60008 | United States Technologies, Inc. | Stempler
February 3, 2016 | 60214 | S. Harman & Associates, Inc. | Prouty
February 3, 2016 | 60310 | Wright Brothers Construction & Supplies | Stempler
February 3, 2016 | 58465 | Kellogg Brown & Root Services, Inc. | Shackleford
February 2, 2016 | 58063 | Delta Engineering, Inc. | Peacock
February 2, 2016 | 59134 | Fluor Enterprises, Inc. | Page
February 2, 2016 | 59390, 60127 | Utron, Inc. | Page
February 2, 2016 | 59793 | BAE Systems San Diego Ship Repair Inc. | Stempler
February 2, 2016 | 59859 | BAE Systems San Diego Ship Repair Inc. | Stempler
February 2, 2016 | 59951 | Task Source/MPSC FEPP, LLC | Prouty
February 2, 2016 | 60156 | RECO Rishad Engineering Construction ORG | Stempler
February 2, 2016 | 60318 | Emerald Town Construction Group | Stempler
January |  |  |
January 28, 2016 | 59883, 60172 | Toro Ventures, LLC | O'Sullivan
January 28, 2016 | 59144, 59145, 59146, 59147, 59148, 59158, 59159, 59182, 59183, 59229, 59274, 59275, 59276, 59277, 59290 | Douglas P. Fleming, LLC | Clarke
January 27, 2016 | 57796, 57888 | Garco Construction, Inc. | Clarke
January 21, 2016 | 59693, 59694 | AeroVironment, Inc. | Peacock
January 21, 2016 | 58773, 58774 | Ball Aerospace & Technologies Corp. | Stempler
January 20, 2016 | 60326 | Potomac Construction Company, Inc. | Stempler
January 19, 2016 | 60038 | Goodloe Marine, Inc. | Stempler
January 19, 2016 | 59626 | RDA Contracting, Inc. | Peacock
January 19, 2016 | 59066, 59227, 59228, 60001 | Femme Comp, Inc. | Peacock
January 19, 2016 | 59045 | Andy Phillips | Thrasher
January 19, 2016 | 59044 | Al Nawars Company | O'Sullivan
January 19, 2016 | 59043 | Al Nawars Company | O'Sullivan
January 19, 2016 | 58583 | Kellogg Brown & Root Services, Inc. | O'Sullivan
January 19, 2016 | 58422 | The Life Eye Company | Younger
January 14, 2016 | 60193 | General Dynamics C4 Systems | Stempler
January 14, 2016 | 59526 | Enola Contracting Services, Inc. | McIlmail
January 13, 2016 | 60252 | Operations Support Technologies, Inc. | Stempler
January 13, 2016 | 59801 | Rand Enterprises, Inc. | Stempler
January 13, 2016 | 59333 | Clauss Construction | O'Sullivan
January 13, 2016 | 59496 | Lewis Limited Consultants, LLC | Stempler
January 13, 2016 | 58220 | Optex Systems, Inc. | O'Sullivan
January 12, 2016 | 58479, 58480, 58481, 58482, 58483, 58486, 58487, 58488 | Vistas Construction of Illinois, Inc. | O'Connell
January 12, 2016 | 58172 | Relyant, LLC | Prouty
January 11, 2016 | 59000 | ANHAM FZCO, LLC | Thrasher
January 11, 2016 | 59260, 59482, 59483 | Tetra Tech EC, Inc. | Thrasher
January 11, 2016 | 58864 | Edinburgh International | Thrasher
January 11, 2016 | 58809 | BAE Systems San Francisco Ship Repair | Ting
January 8, 2016 | 59063 | Baghdadi Swords Company | Stempler
January 7, 2016 | 58372 | Jeffrey C. Stone Inc., d.b.a. Summit Builders | Scott
January 7, 2016 | 59588 | Exelis Federal Services GmbH | Scott
January 7, 2016 | 59320, 59651 | K-Con, Inc. | Newsom
January 7, 2016 | 59752 | Patriot Construction, Inc. | Newsom
January 7, 2016 | 60247 | Fardaye Roshan Logistics & Supply Company | Newsom
January 6, 2016 | 59916 | Shafi Nasimi Construction and Logistics Company | Delman
January 5, 2016 | 58617 | The Boeing Company | Younger
January 5, 2016 | 60123 | Strobe Data, Inc. | Delman
January 4, 2016 | 58974 | The Boeing Company | Stempler
January 4, 2016 | 58948 | AMEC Environment & Infrastructure, Inc. | O'Connell
January 4, 2016 | 59611 | The Boeing Company | Stempler

### Additional Information

### Decisions